import logging.config
from pathlib import Path

from lcconfig import (
    ConsoleSettingsConfig,
    MinioConfig,
)

try:
    import psycopg2
    BACKUP_POSTGRES_DATABASES = True
except ModuleNotFoundError:
    BACKUP_POSTGRES_DATABASES = False

DRAWBRIDGE_SETTINGS_DIR = '/usr/lib/live/mount/persistence/drawbridgeos/etc/drawbridge_portal'
DEFAULT_SETTINGS_DIR = '/etc/compass'
LOGCABIN_SETTINGS_DIR = f'/opt/sap/logcabin_portal'
OPT_DIR = '/opt'
ETC_DIR = '/etc'
if Path(DRAWBRIDGE_SETTINGS_DIR).exists():
    ETC_DIR = '/usr/lib/live/mount/persistence/drawbridgeos/etc'
    OPT_DIR = '/usr/lib/live/mount/persistence/drawbridgeos/opt'
    IS_DRAWBRIDGE = True
elif Path(LOGCABIN_SETTINGS_DIR).exists():
    IS_DRAWBRIDGE = True
else:
    IS_DRAWBRIDGE = False

cfg = ConsoleSettingsConfig().load()
BD = cfg.as_typed_dict('BoxData')
SYSTEM_NAME = BD and BD.get("name") or ''

miniocfg = MinioConfig()
clientcfg = miniocfg.as_typed_dict('Compass')

DAILY_MAX_FILE_COUNT = 7
MONTHLY_MAX_FILE_COUNT = 6
WEEKLY_MAX_FILE_COUNT = 4

log_dir = '/var/log/capsule'
if not Path(log_dir).exists():
    raise SystemExit(f'Log file does not exist: {log_dir}')

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'default_formatter': {
            'format': "[%(asctime)s] %(levelname)s [%(name)s:%(lineno)s] %(message)s",
            'datefmt': "%Y-%m-%d %H:%M:%S",
        },
    },
    'handlers': {
        'file': {
            'level': 'INFO',
            'class': 'logging.FileHandler',
            'filename': f'{log_dir}/capsule.log',
            'formatter': 'default_formatter',
        },
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'default_formatter',
        },
    },
    'loggers': {
        'capsule': {
            'handlers': ['file'],
            'propagate': True,
            'level': 'INFO',
        },
    },
}

logging.config.dictConfig(LOGGING)
