from getpass import getpass

from invoke import task

from capsule.settings import ConsoleSettingsConfig, MinioConfig
from capsule import settings


@task
def setup(ctx):
    """
    Setup minio, system, and email config files for Compass systems.
    """
    setup_minio()
    if settings.IS_DRAWBRIDGE:
        print('Is a Drawbridge system. Not overwriting existing System config and Email config.')
        return
    setup_boxdata()
    setup_email()


def setup_minio():
    """
    Setup minio config file for capsule.
    """
    endpoint = input(
        'Enter Minio endpoint (s3.compassfoundation.io): '
    ) or 's3.compassfoundation.io'
    access_key = input('Enter Minio access key (f7heb3uu): ') or 'f7heb3uu'
    secret_key = ''
    while not secret_key:
        secret_key = getpass('Enter Minio secret key: ')

    MinioConfig().save_section(
        section='Compass',
        data={
            'endpoint': endpoint,
            'access_key': access_key,
            'secret_key': secret_key,
        }
    )


def setup_boxdata():
    """
    Setup System data config file.
    """
    name = ''
    adminurl = ''

    while not name:
        name = input('Enter system name: ')
    while not adminurl:
        adminurl = input('Enter system admin URL: ')

    ConsoleSettingsConfig().save_section(
        section='BoxData', data={
            'name': name,
            'adminurl': adminurl,
        }
    )


def setup_email():
    """
    Setup email config file.
    """
    host = ''
    port = 0
    username = ''
    password = ''
    from_address = ''

    while not host:
        host = input(
            'Enter email server host (smtp2.thesecurityappliance.com): '
        ) or 'smtp2.thesecurityappliance.com'
    while not port or type(port) is not int:
        port = input('Enter email server port (587): ') or 587
        try:
            port = int(port)
        except ValueError:
            pass
    while not username:
        username = input(
            'Enter username (reports@thesecurityappliance.com): '
        ) or 'reports@thesecurityappliance.com'
    while not password:
        password = getpass('Enter password: ')
    while not from_address:
        from_address = input(
            'Enter from address (reports@thesecurityappliance.com): '
        ) or 'reports@thesecurityappliance.com'

    ConsoleSettingsConfig().save_section(
        section='default_email',
        data={
            'host': host,
            'port': port,
            'use_tls': True,
            'username': username,
            'password': password,
            'from_address': from_address,
        }
    )


__all__ = [
    'setup',
]
